@@ -30,6 +30,7 @@
 
 import weakref
 from abc import ABC, abstractmethod
+from typing import Optional
 
 from .net import Channel
 from .net import Connection, ConnectionDelegate
@@ -48,38 +49,47 @@ class StreamHub(BaseHub):
     def delegate(self) -> ConnectionDelegate:
         return self.__delegate()
 
-    def create_connection(self, remote: tuple, local: tuple) -> Connection:
+    # Override
+    def create_connection(self, remote: Optional[tuple], local: Optional[tuple]) -> Connection:
+        # create connection with channel
         sock = self.create_channel(remote=remote, local=local)
-        conn = BaseConnection(channel=sock)
+        conn = BaseConnection(remote=remote, local=local, channel=sock)
+        # set delegate
         if conn.delegate is None:
             conn.delegate = self.delegate
-        conn.start()  # start FSM
+        # start FSM
+        conn.start()
         return conn
 
     @abstractmethod
-    def create_channel(self, remote: tuple, local: tuple) -> Channel:
+    def create_channel(self, remote: Optional[tuple], local: Optional[tuple]) -> Channel:
         raise NotImplemented
 
 
 class ActiveStreamHub(StreamHub, ABC):
     """ Active Stream Hub """
 
-    def create_connection(self, remote: tuple, local: tuple) -> Connection:
+    # Override
+    def create_connection(self, remote: Optional[tuple], local: Optional[tuple]) -> Connection:
+        # create connection with addresses
         conn = ActiveStreamConnection(remote=remote, local=local, hub=self)
+        # set delegate
         if conn.delegate is None:
             conn.delegate = self.delegate
-        conn.start()  # start FSM
+        # start FSM
+        conn.start()
         return conn
 
 
 class ActiveStreamConnection(ActiveConnection):
     """ Active Stream Connection """
 
-    def __init__(self, remote: tuple, local: tuple, hub: ActiveStreamHub):
+    def __init__(self, remote: tuple, local: Optional[tuple], hub: ActiveStreamHub):
         super().__init__(remote=remote, local=local)
         self.__hub = weakref.ref(hub)
 
-    def connect(self, remote: tuple, local: tuple) -> Channel:
+    # Override
+    def connect(self, remote: tuple, local: Optional[tuple] = None) -> Channel:
         hub = self.__hub()
         # assert isinstance(hub, ActiveStreamHub)
         return hub.create_channel(remote=remote, local=local)
